@@ -80,8 +80,8 @@ PLATFORM_CONFIG = {
     },
     "windows": {
         "dockerfile": "Dockerfile.windows-mingw",
-        "image_name": "ccgo-builder-windows",
-        "remote_image": f"{GHCR_REPO}/ccgo-builder-windows:latest",
+        "image_name": "ccgo-builder-windows-mingw",
+        "remote_image": f"{GHCR_REPO}/ccgo-builder-windows-mingw:latest",
         "build_script": "build_windows.py",
         "build_mode": "1",
         "size_estimate": "~1.2GB"
@@ -142,7 +142,7 @@ PLATFORM_CONFIG = {
 class DockerBuilder:
     """Docker-based cross-platform builder."""
 
-    def __init__(self, platform: str, project_dir: str, dev_mode: bool = False, toolchain: str = "auto"):
+    def __init__(self, platform: str, project_dir: str, dev_mode: bool = False, toolchain: str = "auto", link_type: str = "both"):
         """
         Initialize Docker builder.
 
@@ -151,10 +151,12 @@ class DockerBuilder:
             project_dir: Absolute path to project directory
             dev_mode: Use local ccgo source instead of PyPI (for development)
             toolchain: For Windows, specify toolchain: msvc, gnu/mingw, or auto
+            link_type: Library link type: static, shared, or both (default: both)
         """
         self.platform = platform.lower()
         self.project_dir = Path(project_dir).resolve()
         self.toolchain = toolchain.lower() if toolchain else "auto"
+        self.link_type = link_type.lower() if link_type else "both"
         self.docker_dir = Path(__file__).parent.resolve()
 
         # Auto-detect dev mode if not explicitly specified
@@ -351,21 +353,22 @@ class DockerBuilder:
 
     def _find_ccgo_source(self):
         """
-        Find local ccgo source directory (repo root with setup.py).
+        Find local ccgo source directory (repo root with setup.py or pyproject.toml).
 
         This is used in development mode to mount local ccgo source.
 
         Returns:
             Path to ccgo repo root, or None if not found
         """
-        # Start from docker_dir and search upward for setup.py
+        # Start from docker_dir and search upward for setup.py or pyproject.toml
         # docker_dir is .../ccgo/ccgo/dockers
-        # We need to find .../ccgo (repo root with setup.py)
+        # We need to find .../ccgo (repo root with setup.py or pyproject.toml)
         current = self.docker_dir
         for _ in range(5):  # Search up to 5 levels
             parent = current.parent
             setup_py = parent / "setup.py"
-            if setup_py.exists():
+            pyproject_toml = parent / "pyproject.toml"
+            if setup_py.exists() or pyproject_toml.exists():
                 # Verify it's the ccgo repo by checking for ccgo package
                 ccgo_dir = parent / "ccgo"
                 if ccgo_dir.exists() and ccgo_dir.is_dir():
@@ -374,6 +377,47 @@ class DockerBuilder:
 
         return None
 
+    def _find_git_root(self):
+        """
+        Find git repository root by searching upward from project directory.
+
+        The .git directory may be in the project directory itself or in a parent
+        directory. This method searches upward to find the git root.
+
+        Returns:
+            Path to .git directory, or None if not found
+        """
+        current = self.project_dir
+        for _ in range(10):  # Search up to 10 levels
+            git_dir = current / ".git"
+            if git_dir.exists():
+                # .git can be a directory (normal repo) or a file (worktree/submodule)
+                if git_dir.is_dir():
+                    # Verify it's a valid git directory by checking for HEAD file
+                    head_file = git_dir / "HEAD"
+                    if head_file.exists():
+                        return git_dir
+                    # Empty .git directory (possibly created by Docker), skip it
+                elif git_dir.is_file():
+                    # Handle git worktree or submodule
+                    # The file contains: "gitdir: /path/to/actual/.git/worktrees/xxx"
+                    try:
+                        with open(git_dir, 'r') as f:
+                            content = f.read().strip()
+                            if content.startswith('gitdir:'):
+                                # Valid git worktree/submodule reference
+                                return git_dir
+                    except Exception:
+                        pass
+            # Move to parent directory
+            parent = current.parent
+            if parent == current:
+                # Reached filesystem root
+                break
+            current = parent
+
+        return None
+
     def run_build(self, build_args: list = None):
         """
         Run build inside Docker container using ccgo command.
@@ -384,18 +428,36 @@ class DockerBuilder:
         print(f"\n=== Running {self.platform} build in Docker container ===")
         print(f"Project directory: {self.project_dir}")
 
+        # Clean target/{platform} directory before Docker build to avoid stale artifacts
+        target_platform_dir = Path(self.project_dir) / "target" / self.platform
+        if target_platform_dir.exists():
+            shutil.rmtree(target_platform_dir)
+            print(f"Cleaned up: {target_platform_dir}")
+
         # Determine installation method based on dev_mode
         docker_volumes = [
             "-v", f"{self.project_dir}:/workspace",  # Always mount project directory
         ]
 
+        # Mount .git directory if found (for git info in build_info.json)
+        # The .git may be in parent directory, so we search upward
+        git_dir = self._find_git_root()
+        if git_dir:
+            # Mount .git to /workspace/.git so git commands work in container
+            docker_volumes.extend(["-v", f"{git_dir}:/workspace/.git:ro"])
+            print(f"Git repository: {git_dir.parent} (mounted .git to container)")
+        else:
+            print(f"⚠ No git repository found (git info will be 'unknown')")
+
         if self.dev_mode:
             # Development mode: Use local ccgo source
             ccgo_source = self._find_ccgo_source()
             if ccgo_source:
                 print(f"Development mode: Using local ccgo source from {ccgo_source}")
                 docker_volumes.extend(["-v", f"{ccgo_source}:/ccgo"])
-                install_cmd = "pip3 install -q -e /ccgo"
+                # Use non-editable install to avoid PEP 660 compatibility issues in containers
+                # Upgrade pip first to support --break-system-packages if needed (for newer Ubuntu)
+                install_cmd = "pip3 install -q --upgrade pip && pip3 install -q /ccgo"
             else:
                 print("⚠ Development mode requested but ccgo source not found!")
                 print("  Falling back to PyPI installation")
@@ -403,22 +465,32 @@ class DockerBuilder:
 
         if not self.dev_mode:
             # Production mode: Install from PyPI with version matching
+            # Upgrade pip first to ensure compatibility
             ccgo_version = self._get_ccgo_version()
             if ccgo_version:
                 print(f"CCGO version: {ccgo_version} (will install same version in container)")
-                install_cmd = f"pip3 install -q ccgo=={ccgo_version}"
+                install_cmd = f"pip3 install -q --upgrade pip && pip3 install -q ccgo=={ccgo_version}"
             else:
                 print(f"CCGO installation: Latest from PyPI (version not detected)")
-                install_cmd = f"pip3 install -q ccgo"
+                install_cmd = f"pip3 install -q --upgrade pip && pip3 install -q ccgo"
 
         # Construct ccgo build command
-        if self.platform == "android" and self.config.get("native_only"):
-            # Android native-only build
-            ccgo_cmd = f"ccgo build android --native-only --arch armeabi-v7a,arm64-v8a,x86_64 --no-docker"
+        # Use python3 -m ccgo.main instead of ccgo command to avoid PATH issues in Docker
+        link_type_arg = f" --link-type {self.link_type}" if self.link_type else ""
+
+        # Map Docker platform to ccgo build target
+        # windows-msvc and windows-mingw both map to "windows" build target
+        build_target = self.platform
+        if self.platform.startswith("windows-"):
+            build_target = "windows"
+
+        if self.platform == "android":
+            # Android build in Docker: native-only with archive (no Gradle in Docker)
+            ccgo_cmd = f"python3 -m ccgo.main build android --native-only --archive --arch armeabi-v7a,arm64-v8a,x86_64 --no-docker{link_type_arg}"
         else:
             # Standard build command
             # IMPORTANT: Add --no-docker to prevent recursive Docker calls inside container
-            ccgo_cmd = f"ccgo build {self.platform} --no-docker"
+            ccgo_cmd = f"python3 -m ccgo.main build {build_target} --no-docker{link_type_arg}"
 
         if build_args:
             ccgo_cmd += " " + " ".join(build_args)
@@ -511,8 +583,10 @@ def print_usage():
     print("\nOptions:")
     print("  --dev              Use local ccgo source (for development, not published to PyPI)")
     print("  --toolchain=<type> Windows toolchain: msvc, gnu/mingw, or auto (default: auto)")
+    print("  --link-type=<type> Library link type: static, shared, or both (default: both)")
     print("\nExamples:")
     print("  python3 build_docker.py linux /path/to/project")
+    print("  python3 build_docker.py linux /path/to/project --link-type=static")
     print("  python3 build_docker.py windows /path/to/project --dev")
     print("  python3 build_docker.py windows /path/to/project --toolchain=msvc")
     print("  python3 build_docker.py windows /path/to/project --toolchain=mingw")
@@ -530,9 +604,10 @@ def main():
     platform = sys.argv[1]
     project_dir = sys.argv[2]
 
-    # Parse --dev flag, --toolchain flag and remaining build args
+    # Parse --dev flag, --toolchain flag, --link-type flag and remaining build args
     dev_mode = False
     toolchain = "auto"
+    link_type = "both"
     build_args = []
 
     for arg in sys.argv[3:]:
@@ -540,6 +615,8 @@ def main():
             dev_mode = True
         elif arg.startswith("--toolchain="):
             toolchain = arg.split("=", 1)[1]
+        elif arg.startswith("--link-type="):
+            link_type = arg.split("=", 1)[1]
         else:
             build_args.append(arg)
 
@@ -547,15 +624,80 @@ def main():
         build_args = None
 
     try:
-        builder = DockerBuilder(platform, project_dir, dev_mode=dev_mode, toolchain=toolchain)
-        builder.check_docker()
-        builder.build_image()
-        builder.run_build(build_args)
-        builder.print_results()
+        # Special handling for Windows with auto toolchain: build both MinGW and MSVC
+        if platform.lower() == "windows" and toolchain == "auto":
+            print("\n" + "=" * 60)
+            print("Windows build with auto toolchain: Building both MinGW and MSVC")
+            print("=" * 60)
 
-        print("\n" + "=" * 60)
-        print(f"✓ Docker build for {platform} completed successfully!")
-        print("=" * 60)
+            # Check Docker once
+            temp_builder = DockerBuilder(platform, project_dir, dev_mode=dev_mode, toolchain="mingw", link_type=link_type)
+            temp_builder.check_docker()
+
+            # Build MinGW first (without archive - we'll archive at the end on host)
+            print("\n" + "=" * 60)
+            print("Step 1/2: Building with MinGW toolchain")
+            print("=" * 60)
+            mingw_builder = DockerBuilder(platform, project_dir, dev_mode=dev_mode, toolchain="mingw", link_type=link_type)
+            mingw_builder.build_image()
+            # Add --no-archive flag for MinGW build
+            mingw_args = list(build_args) if build_args else []
+            mingw_args.append("--no-archive")
+            mingw_builder.run_build(mingw_args)
+
+            # Build MSVC second (also without archive - we'll archive on host)
+            print("\n" + "=" * 60)
+            print("Step 2/2: Building with MSVC toolchain")
+            print("=" * 60)
+            msvc_builder = DockerBuilder(platform, project_dir, dev_mode=dev_mode, toolchain="msvc", link_type=link_type)
+            msvc_builder.build_image()
+            # MSVC build without archive
+            msvc_args = list(build_args) if build_args else []
+            msvc_args.append("--no-archive")
+            msvc_builder.run_build(msvc_args)
+
+            # Archive on host machine (after both Docker builds are complete)
+            # This ensures we can see all build outputs from both toolchains
+            print("\n" + "=" * 60)
+            print("Archiving both toolchains on host...")
+            print("=" * 60)
+            try:
+                # Add the ccgo build_scripts directory to Python path
+                ccgo_build_scripts = Path(__file__).parent.parent / "build_scripts"
+                if str(ccgo_build_scripts) not in sys.path:
+                    sys.path.insert(0, str(ccgo_build_scripts))
+
+                # Change to project directory and import build_windows
+                original_cwd = os.getcwd()
+                os.chdir(project_dir)
+
+                # Import and call archive function
+                from build_windows import archive_windows_project, print_build_results
+                archive_windows_project(link_type=link_type, toolchain='auto')
+                print_build_results(link_type=link_type)
+
+                os.chdir(original_cwd)
+            except Exception as e:
+                print(f"WARNING: Archive on host failed: {e}")
+                import traceback
+                traceback.print_exc()
+
+            print("\n" + "=" * 60)
+            print(f"✓ Docker build for {platform} completed successfully!")
+            print("  - MinGW libraries: lib/static/mingw/, lib/shared/mingw/")
+            print("  - MSVC libraries:  lib/static/msvc/, lib/shared/msvc/")
+            print("=" * 60)
+        else:
+            # Standard single-toolchain build
+            builder = DockerBuilder(platform, project_dir, dev_mode=dev_mode, toolchain=toolchain, link_type=link_type)
+            builder.check_docker()
+            builder.build_image()
+            builder.run_build(build_args)
+            builder.print_results()
+
+            print("\n" + "=" * 60)
+            print(f"✓ Docker build for {platform} completed successfully!")
+            print("=" * 60)
 
     except Exception as e:
         print(f"\nERROR: {e}")
